Welcome to Datenguide Python's documentation!
=============================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   step_by_step_intro 
   helper_functions
   enums
   output_modification
   pitfalls
   modules
   contributing
   history

Indices and tables
===================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
